@@ -16,6 +16,9 @@ from .exceptions import (
     NonroutableAddressError,
 )
 
+logging.basicConfig(
+    level=logging.INFO, format="[%(levelname)s] %(name)s: %(message)s"
+)
 logger = logging.getLogger(__name__)
 
 AS_SERVICES = {
